@@ -1,10 +1,10 @@
 import logging
 from datetime import datetime
 import json
-from decouple import config
+from decouple import AutoConfig
 import requests
 
-
+config = AutoConfig(search_path='/var/www/html/pytestee')
 
 
 def _log(msg, application, level,execution_time, environment, user_id=None, extra_data=None):
